============
Installation
============

At the command line::

    $ easy_install federated_monsters

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv federated_monsters
    $ pip install federated_monsters